==> flutter_slick-1.1.3.tar.gz: lib/navigation/paths_builder.dart <==
import 'package:flutter/widgets.dart';

import 'route_builder.dart';
import 'route_path.dart';

class PathsBuilder {
  final RegExp pattern;
  final String Function(String) path;
  final List<PathsBuilder> paths;
  final List<RouteBuilder> builders;
  final Widget Function() notFoundScreen;

  PathsBuilder({
    required this.pattern,
    required this.path,
    required this.paths,
    required this.builders,
    required this.notFoundScreen,
  });

  RouteBuilder bareBuilder(
    String path,
    Widget Function() screen,
  ) {
    return RouteBuilder(
      getBuilder: () => this,
      pattern: RegExp(''),
      parse: (_, __) => RouteArguments(),
      path: (_) => path,
      build: (_, __) async => screen(),
      rewrite: (_) async => null,
    );
  }

  RoutePath build(String path, Uri uri) {
    // Adjust the path according to the pattern
    var subPath = pattern.allMatches(path).first.group(1);
    // Return not found if no sub path is found
    if (subPath == null) return bareBuilder('', notFoundScreen)();
    // Look for a matchin sub path
    var subPathsBuilder = paths.firstWhere(
      (o) => o.pattern.hasMatch(subPath),
      orElse: () => this,
    );
    // Use sub path if matched
    if (subPathsBuilder != this) {
      return subPathsBuilder.build(subPath, uri);
    } else {
      // Look for a mathcing builder
      var builder = builders.firstWhere(
        (o) => o.pattern.hasMatch(subPath),
        orElse: () => bareBuilder(subPath, notFoundScreen),
      );
      // Collect the segments for the path
      RouteSegments segments;
      var match = builder.pattern.firstMatch(subPath);
      if (match == null) {
        segments = {};
      } else {
        var groupNames = match.groupNames.map((o) => [o, match.namedGroup(o)]);
        segments = {for (var o in groupNames) '${o[0]}': o[1]};
      }
      // Build and return the route path
      return builder(segments, uri.queryParametersAll);
    }
  }
}

==> flutter_slick-3.6.1.tar.gz: lib/navigation/paths_builder.dart <==
import 'package:flutter/widgets.dart';

import 'route_builder.dart';
import 'route_path.dart';

class PathsBuilder {
  final RegExp pattern;
  final String Function(String) path;
  final List<PathsBuilder> paths;
  final List<RouteBuilder> builders;
  final Widget Function() notFoundScreen;

  PathsBuilder({
    required this.pattern,
    required this.path,
    required this.paths,
    required this.builders,
    required this.notFoundScreen,
  });

  RouteBuilder bareBuilder(
    String path,
    Widget Function() screen,
  ) {
    return RouteBuilder(
      getBuilder: () => this,
      pattern: RegExp(''),
      parse: (_, __) => RouteArguments(),
      path: (_) => path,
      build: (_, __) async => screen(),
      rewrite: (_, __) async => null,
    );
  }

  RoutePath build(String path, Uri uri) {
    // Adjust the path according to the pattern
    var subPath = pattern.allMatches(path).first.group(1);
    // Return not found if no sub path is found
    if (subPath == null) return bareBuilder('', notFoundScreen)();
    // Look for a matchin sub path
    var subPathsBuilder = paths.firstWhere(
      (o) => o.pattern.hasMatch(subPath),
      orElse: () => this,
    );
    // Use sub path if matched
    if (subPathsBuilder != this) {
      return subPathsBuilder.build(subPath, uri);
    } else {
      // Look for a mathcing builder
      var builder = builders.firstWhere(
        (o) => o.pattern.hasMatch(subPath),
        orElse: () => bareBuilder(subPath, notFoundScreen),
      );
      // Collect the segments for the path
      RouteSegments segments;
      var match = builder.pattern.firstMatch(subPath);
      if (match == null) {
        segments = {};
      } else {
        var groupNames = match.groupNames.map((o) => [o, match.namedGroup(o)]);
        segments = {for (var o in groupNames) '${o[0]}': o[1]};
      }
      // Build and return the route path
      return builder(segments, uri.queryParametersAll);
    }
  }
}
